@@ -2,17 +2,18 @@
 """
 Advanced Stores for behavior outside normal access patterns
 """
-import os
 import json
-from typing import Union, Optional, Dict, List, Iterator, Tuple
+import os
+from typing import Dict, Iterator, List, Optional, Tuple, Union
 
-from monty.dev import requires
-from maggma.core import Store, StoreError, Sort
-from maggma.stores.mongolike import MongoStore
-from maggma.utils import lazy_substitute, substitute
 from mongogrant import Client
 from mongogrant.client import check
 from mongogrant.config import Config
+from monty.dev import requires
+
+from maggma.core import Sort, Store, StoreError
+from maggma.stores.mongolike import MongoStore
+from maggma.utils import lazy_substitute, substitute
 
 try:
     import hvac
@@ -21,7 +22,7 @@ except ImportError:
 
 
 class MongograntStore(MongoStore):
-    """Initialize a Store with a mongogrant "<role>:<host>/<db>." spec.
+    """Initialize a Store with a mongogrant "`<role>`:`<host>`/`<db>`." spec.
 
     Some class methods of MongoStore, e.g. from_db_file and from_collection,
     are not supported.
@@ -38,7 +39,7 @@ class MongograntStore(MongoStore):
     ):
         """
         Args:
-            mongogrant_spec: of the form <role>:<host>/<db>, where
+            mongogrant_spec: of the form `<role>`:`<host>`/`<db>`, where
                 role is one of {"read", "readWrite"} or aliases {"ro", "rw"};
                 host is a db host (w/ optional port) or alias; and db is a db
                 on that host, or alias. See mongogrant documentation.
